@@ -2,7 +2,7 @@
 /**
  * This file is part of PHP Mess Detector.
  *
- * Copyright (c) 2008-2012, Manuel Pichler <mapi@phpmd.org>.
+ * Copyright (c) 2008-2017, Manuel Pichler <mapi@phpmd.org>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,9 +34,9 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @author    Manuel Pichler <mapi@phpmd.org>
- * @copyright 2008-2014 Manuel Pichler. All rights reserved.
- * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @author Manuel Pichler <mapi@phpmd.org>
+ * @copyright 2008-2017 Manuel Pichler. All rights reserved.
+ * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 
 namespace PHPMD\Rule\CleanCode;
@@ -57,8 +57,8 @@ use PHPMD\Rule\MethodAware;
  * and is a bad practice.
  *
  * @author    Benjamin Eberlei <benjamin@qafoo.com>
- * @copyright 2008-2014 Manuel Pichler. All rights reserved.
- * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright 2008-2017 Manuel Pichler. All rights reserved.
+ * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 class StaticAccess extends AbstractRule implements MethodAware, FunctionAware
 {
@@ -87,7 +87,7 @@ class StaticAccess extends AbstractRule implements MethodAware, FunctionAware
         }
     }
 
-    private function isStaticMethodCall($methodCall)
+    private function isStaticMethodCall(AbstractNode $methodCall)
     {
         return $methodCall->getChild(0)->getNode() instanceof ASTClassOrInterfaceReference &&
                $methodCall->getChild(1)->getNode() instanceof ASTMethodPostfix &&
@@ -95,12 +95,12 @@ class StaticAccess extends AbstractRule implements MethodAware, FunctionAware
                !$this->isCallingSelf($methodCall);
     }
 
-    private function isCallingParent($methodCall)
+    private function isCallingParent(AbstractNode $methodCall)
     {
         return $methodCall->getChild(0)->getNode() instanceof ASTParentReference;
     }
 
-    private function isCallingSelf($methodCall)
+    private function isCallingSelf(AbstractNode $methodCall)
     {
         return $methodCall->getChild(0)->getNode() instanceof ASTSelfReference;
     }
